brick_sqlite library

Classes

RuntimeSqliteColumnDefinition
Used to define types in SqliteAdapter#fieldsToSqliteColumns. The build runner package extracts types and associations that would've been otherwise inaccessible at runtime.
Sqlite
An annotation used to specify how a field is serialized. Heavily inspired by JsonKey
SqliteAdapter<TModel extends Model>
Constructors that convert app models to and from Sqlite
SqliteModel
Models accessible to the SqliteProvider.
SqliteModelDictionary
Associates app models with their SqliteAdapter
SqliteProvider<TProviderModel extends SqliteModel>
Retrieves from a SQLite database
SqliteProviderQuery
SqliteProvider-specific options for a Query
SqliteSerializable
An annotation used to specify a class to generate code for.

Enums

Column
SQLite data types.

Constants

NEW_RECORD_ID → const int?
The default value of the primaryKey field.